Documentation
#############

NetworkCore
***********

TaggableObject
==============

.. automodule:: pymonntorch.NetworkCore.TaggableObject
    :members:

Behavior
========

.. automodule:: pymonntorch.NetworkCore.Behavior
    :members:

NetworkObjects
==============

.. automodule:: pymonntorch.NetworkCore.Base
    :members:

Network
=======

.. automodule:: pymonntorch.NetworkCore.Network
    :members:

NeuronGroup
===========

.. automodule:: pymonntorch.NetworkCore.NeuronGroup
    :members:

SynapseGroup
============

.. automodule:: pymonntorch.NetworkCore.SynapseGroup
    :members:

NetworkBehavior
***************

Recorder
========

.. automodule:: pymonntorch.NetworkBehavior.Recorder.Recorder
    :members:

Structure
=========

.. automodule:: pymonntorch.NetworkBehavior.Structure.Structure
    :members:

Basics
======

.. automodule:: pymonntorch.NetworkBehavior.Basics.BasicHomeostasis
    :members:

.. automodule:: pymonntorch.NetworkBehavior.Basics.Normalization
    :members: